#! /usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (c) 2008 Manuel Holtgrewe, Mathias Ziebarth, Lucas Lürich, Joachim Breitner
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


import unittest

import sevendown.util as su
import sevendown.undo as undo

class TestCase(unittest.TestCase):
    def setUp(self):
        undo.setUp()
    
    def tearDown(self):
        undo.tearDown()
    
    def assertSetEqual(self,s1,s2):
        self.assertEqual(set(s1),set(s2))
    
    def assertSetNotEqual(self,s1,s2):
        self.assertNotEqual(set(s1),set(s2))
    

class TestSquareNumbers(unittest.TestCase):
    """Test the square_numbers function."""
    
    def testIt(self):
        self.assertEqual(list(su.pot_numbers(2, 10,14)), [9])
        self.assertEqual(list(su.pot_numbers(2, 0, 100)),
            [0, 1, 4, 9, 16, 25, 36, 49, 64, 81])
    

class TestCubeNumbers(unittest.TestCase):
    """Test the cube_numbers function."""

    def testIt(self):
        self.assertEqual(list(su.pot_numbers(3, 9,15)), [8])
        self.assertEqual(list(su.pot_numbers(3, 0, 100)),
            [0, 1, 8, 27, 64])
    

class TestUtilityFunctions(TestCase):
    def testDigits(self):
        self.assertEqual(su.digits(123), [1,2,3])
        self.assertEqual(su.digits(123,3), [1,2,3])
        self.assertEqual(su.digits(3,1), [3])
        self.assertEqual(su.digits(3,3), [0,0,3])
        self.assertEqual(su.digits(1234,3), None)
        self.assertEqual(su.digits(1234,4), [1,2,3,4])
    
    def testFactorsOf(self):
        self.assertEqual(su.factors_of(0), set(range(10)))
        self.assertEqual(su.factors_of(1), set([1,3,9,7]))
        self.assertEqual(su.factors_of(9), set([1,3,9,7]))

    def testGcd(self):
        self.assertEqual(su.gcd(12,4), 4)
        self.assertEqual(su.gcd(12,5), 1)
        self.assertEqual(su.gcd(10,5), 5)
        self.assertEqual(su.gcd(0,5), 5)
        self.assertEqual(su.gcd(5,0), 5)
        self.assertEqual(su.gcd(200,200), 200)
    
    def testGcdList(self):
        self.assertEqual(su.gcdList((1,)), 1)
        self.assertEqual(su.gcdList((1,2)), 1)
        self.assertEqual(su.gcdList((3,2)), 1)
        self.assertEqual(su.gcdList((6,4,8)), 2)
    

# Execute unit tests when called standalone.
if __name__ == "__main__":
    unittest.main()

# vim:sw=4:ts=4:sts=4:expandtab
